@@ -29,10 +29,13 @@ System System2020 = {
     .pension_age = 65,
     .mxo_single = 2230,
     .mxo_couple = 1602,
-    .lwr_single = 33622,
-    .lwr_couple = 30316,
-    .upr_single = 51462,
-    .upr_couple = 43132,
+    .mxo_illness = 2040,
+    .lwr_single = 32279,
+    .lwr_couple = 28974,
+    .lwr_illness = 31279,
+    .upr_single = 50119,
+    .upr_couple = 83580,
+    .upr_illness = 95198,
     .taper = 0.125,
     .first_tax_rate = 0.19,
     .second_tax_rate = 0.325,
