@@ -17,25 +17,28 @@ System System2021 = {
     .lwr_family = 39167,
     .upr_family = 48959,
     .has_sapto_thr = true,
-    .sapto_age = 65,
+    .sapto_age = 66,
     .lwr_single_sapto = 36056,
     .upr_single_sapto = 45071,
     .lwr_family_sapto = 51094,
     .upr_family_sapto = 63868,
-    .lwr_thr_up_per_child = 3533,
+    .lwr_thr_up_per_child = 3597,
     .taper = 0.1,
     .rate = 0.02
   },
   .has_sapto = true,
   .S = {
     .year = 2021,
-    .pension_age = 65,
+    .pension_age = 66.5,
     .mxo_single = 2230,
     .mxo_couple = 1602,
-    .lwr_single = 33622,
-    .lwr_couple = 30316,
-    .upr_single = 51462,
-    .upr_couple = 43132,
+    .mxo_illness = 2040,
+    .lwr_single = 32279,
+    .lwr_couple = 28974,
+    .lwr_illness = 31279,
+    .upr_single = 50119,
+    .upr_couple = 83580,
+    .upr_illness = 95198,
     .taper = 0.125,
     .first_tax_rate = 0.19,
     .second_tax_rate = 0.325,
